@@ -32,13 +32,13 @@
 #include "fr-command.h"
 #include "fr-command-lha.h"
 
-static void fr_command_lha_class_init  (FRCommandLhaClass *class);
-static void fr_command_lha_init        (FRCommand         *afile);
+static void fr_command_lha_class_init  (FrCommandLhaClass *class);
+static void fr_command_lha_init        (FrCommand         *afile);
 static void fr_command_lha_finalize    (GObject           *object);
 
 /* Parent Class */
 
-static FRCommandClass *parent_class = NULL;
+static FrCommandClass *parent_class = NULL;
 
 
 /* -- list -- */
@@ -107,11 +107,16 @@ split_line_lha (char *line)
 		fields[i++] = g_strdup ("");
 		fields[i++] = g_strdup ("");
 		line += strlen ("[MS-DOS]");
-
-	} else if (strncmp (line, "[generic]", 9) == 0) {
+	} 
+	else if (strncmp (line, "[generic]", 9) == 0) {
 		fields[i++] = g_strdup ("");
 		fields[i++] = g_strdup ("");
 		line += strlen ("[generic]");
+	} 
+	else if (strncmp (line, "[unknown]", 9) == 0) {
+		fields[i++] = g_strdup ("");
+		fields[i++] = g_strdup ("");
+		line += strlen ("[unknown]");
 	}
 
 	scan = eat_spaces (line);
@@ -140,6 +145,9 @@ get_last_field_lha (char *line)
 	if (strncmp (line, "[generic]", 9) == 0) 
 		n--;
 
+	if (strncmp (line, "[unknown]", 9) == 0) 
+		n--;
+
 	field = eat_spaces (line);
 	for (i = 0; i < n; i++) {
 		field = strchr (field, ' ');
@@ -155,7 +163,7 @@ process_line (char     *line,
 	      gpointer  data)
 {
 	FileData    *fdata;
-	FRCommand   *comm = FR_COMMAND (data);
+	FrCommand   *comm = FR_COMMAND (data);
 	char       **fields;
 	const char  *name_field;
 
@@ -174,7 +182,7 @@ process_line (char     *line,
 
 	name_field = get_last_field_lha (line);
 
-	if (*name_field == '/') {
+	if (name_field && *name_field == '/') {
 		fdata->full_path = g_strdup (name_field);
 		fdata->original_path = fdata->full_path;
 	} else {
@@ -200,7 +208,7 @@ process_line (char     *line,
 
 
 static void
-fr_command_lha_list (FRCommand  *comm,
+fr_command_lha_list (FrCommand  *comm,
 		     const char *password)
 {
 	fr_process_set_out_line_func (FR_COMMAND (comm)->process, 
@@ -216,7 +224,7 @@ fr_command_lha_list (FRCommand  *comm,
 
 
 static void
-fr_command_lha_add (FRCommand     *comm,
+fr_command_lha_add (FrCommand     *comm,
 		    GList         *file_list,
 		    const char    *base_dir,
 		    gboolean       update,
@@ -240,7 +248,7 @@ fr_command_lha_add (FRCommand     *comm,
 
 
 static void
-fr_command_lha_delete (FRCommand *comm,
+fr_command_lha_delete (FrCommand *comm,
 		       GList     *file_list)
 {
 	GList *scan;
@@ -256,7 +264,7 @@ fr_command_lha_delete (FRCommand *comm,
 
 
 static void
-fr_command_lha_extract (FRCommand  *comm,
+fr_command_lha_extract (FrCommand  *comm,
 			GList      *file_list,
 			const char *dest_dir,
 			gboolean    overwrite,
@@ -295,13 +303,13 @@ fr_command_lha_extract (FRCommand  *comm,
 
 
 static void 
-fr_command_lha_class_init (FRCommandLhaClass *class)
+fr_command_lha_class_init (FrCommandLhaClass *class)
 {
         GObjectClass   *gobject_class = G_OBJECT_CLASS (class);
-        FRCommandClass *afc;
+        FrCommandClass *afc;
 
         parent_class = g_type_class_peek_parent (class);
-	afc = (FRCommandClass*) class;
+	afc = (FrCommandClass*) class;
 
 	gobject_class->finalize = fr_command_lha_finalize;
 
@@ -313,7 +321,7 @@ fr_command_lha_class_init (FRCommandLhaClass *class)
 
  
 static void 
-fr_command_lha_init (FRCommand *comm)
+fr_command_lha_init (FrCommand *comm)
 {
 	comm->file_type = FR_FILE_TYPE_LHA;
 
@@ -347,13 +355,13 @@ fr_command_lha_get_type ()
 
         if (! type) {
                 GTypeInfo type_info = {
-			sizeof (FRCommandLhaClass),
+			sizeof (FrCommandLhaClass),
 			NULL,
 			NULL,
 			(GClassInitFunc) fr_command_lha_class_init,
 			NULL,
 			NULL,
-			sizeof (FRCommandLha),
+			sizeof (FrCommandLha),
 			0,
 			(GInstanceInitFunc) fr_command_lha_init
 		};
@@ -368,11 +376,11 @@ fr_command_lha_get_type ()
 }
 
 
-FRCommand *
-fr_command_lha_new (FRProcess  *process,
+FrCommand *
+fr_command_lha_new (FrProcess  *process,
 		    const char *filename)
 {
-	FRCommand *comm;
+	FrCommand *comm;
 
 	if (!is_program_in_path("lha")) {
 		return NULL;
