@@ -33,13 +33,13 @@
 #include "fr-command.h"
 #include "fr-command-rpm.h"
 
-static void fr_command_rpm_class_init  (FRCommandRpmClass *class);
-static void fr_command_rpm_init        (FRCommand         *afile);
+static void fr_command_rpm_class_init  (FrCommandRpmClass *class);
+static void fr_command_rpm_init        (FrCommand         *afile);
 static void fr_command_rpm_finalize    (GObject           *object);
 
 /* Parent Class */
 
-static FRCommandClass *parent_class = NULL;
+static FrCommandClass *parent_class = NULL;
 
 
 /* -- list -- */
@@ -87,7 +87,7 @@ list__process_line (char     *line,
 		    gpointer  data)
 {
 	FileData    *fdata;
-	FRCommand   *comm = FR_COMMAND (data);
+	FrCommand   *comm = FR_COMMAND (data);
 	char       **fields;
 	const char  *name_field;
 
@@ -144,7 +144,7 @@ list__process_line (char     *line,
 
 
 static void
-fr_command_rpm_list (FRCommand  *comm,
+fr_command_rpm_list (FrCommand  *comm,
 		     const char *password)
 {
 	fr_process_set_out_line_func (FR_COMMAND (comm)->process, 
@@ -160,7 +160,7 @@ fr_command_rpm_list (FRCommand  *comm,
 
 
 static void
-fr_command_rpm_extract (FRCommand  *comm,
+fr_command_rpm_extract (FrCommand  *comm,
 			GList      *file_list,
 			const char *dest_dir,
 			gboolean    overwrite,
@@ -185,13 +185,13 @@ fr_command_rpm_extract (FRCommand  *comm,
 
 
 static void 
-fr_command_rpm_class_init (FRCommandRpmClass *class)
+fr_command_rpm_class_init (FrCommandRpmClass *class)
 {
         GObjectClass   *gobject_class = G_OBJECT_CLASS (class);
-        FRCommandClass *afc;
+        FrCommandClass *afc;
 
         parent_class = g_type_class_peek_parent (class);
-	afc = (FRCommandClass*) class;
+	afc = (FrCommandClass*) class;
 
 	gobject_class->finalize = fr_command_rpm_finalize;
 
@@ -201,7 +201,7 @@ fr_command_rpm_class_init (FRCommandRpmClass *class)
 
  
 static void 
-fr_command_rpm_init (FRCommand *comm)
+fr_command_rpm_init (FrCommand *comm)
 {
 	comm->file_type = FR_FILE_TYPE_RPM;
 
@@ -235,13 +235,13 @@ fr_command_rpm_get_type ()
 
         if (! type) {
                 GTypeInfo type_info = {
-			sizeof (FRCommandRpmClass),
+			sizeof (FrCommandRpmClass),
 			NULL,
 			NULL,
 			(GClassInitFunc) fr_command_rpm_class_init,
 			NULL,
 			NULL,
-			sizeof (FRCommandRpm),
+			sizeof (FrCommandRpm),
 			0,
 			(GInstanceInitFunc) fr_command_rpm_init
 		};
@@ -256,11 +256,11 @@ fr_command_rpm_get_type ()
 }
 
 
-FRCommand *
-fr_command_rpm_new (FRProcess  *process,
+FrCommand *
+fr_command_rpm_new (FrProcess  *process,
 		    const char *filename)
 {
-	FRCommand *comm;
+	FrCommand *comm;
 
 	if (!is_program_in_path("rpm2cpio")) {
 		return NULL;
