@@ -35,13 +35,13 @@
 
 #define EMPTY_ARCHIVE_WARNING        "Empty zipfile."
 
-static void fr_command_zip_class_init  (FRCommandZipClass *class);
-static void fr_command_zip_init        (FRCommand         *afile);
+static void fr_command_zip_class_init  (FrCommandZipClass *class);
+static void fr_command_zip_init        (FrCommand         *afile);
 static void fr_command_zip_finalize    (GObject           *object);
 
 /* Parent Class */
 
-static FRCommandClass *parent_class = NULL;
+static FrCommandClass *parent_class = NULL;
 
 
 /* -- list -- */
@@ -55,9 +55,9 @@ mktime_from_string (char *datetime_s)
 	char      *year;
 	char      *month;
 	char      *day;
-        char      *hour;
-        char      *min;
-        char      *sec;
+	char      *hour;
+	char      *min;
+	char      *sec;
 
 	/* date */
 
@@ -90,7 +90,7 @@ mktime_from_string (char *datetime_s)
 
 
 static char *
-fr_command_zip_escape (FRCommand     *comm,
+fr_command_zip_escape (FrCommand     *comm,
 		       const char    *str)
 {
 	char *estr;
@@ -102,7 +102,7 @@ fr_command_zip_escape (FRCommand     *comm,
 	g_free (estr);
 
 	return estr2;
-	
+
 }
 
 
@@ -116,9 +116,9 @@ zip_escape (const char *str)
 static char*
 prepend_path_separator (const char *str)
 {
-	if (*str == '-' || g_str_has_prefix (str, "\\-")) 
+	if (*str == '-' || g_str_has_prefix (str, "\\-"))
 		return g_strconcat (".", G_DIR_SEPARATOR_S, str, NULL);
-	else 
+	else
 		return g_strdup (str);
 }
 
@@ -131,17 +131,17 @@ prepend_path_separator_zip_escape (const char *str)
 	tmp2 = prepend_path_separator (str);
 	tmp1 = zip_escape (tmp2);
 	g_free (tmp2);
-	
+
 	return tmp1;
 }
 
 
 static void
-list__process_line (char     *line, 
+list__process_line (char     *line,
 		    gpointer  data)
 {
 	FileData    *fdata;
-	FRCommand   *comm = FR_COMMAND (data);
+	FrCommand   *comm = FR_COMMAND (data);
 	char       **fields;
 	const char  *name_field;
 	gint         line_l;
@@ -158,8 +158,7 @@ list__process_line (char     *line,
 	if (line_l == 0)
 		return;
 
-	if (strcmp (line,
-		    EMPTY_ARCHIVE_WARNING) == 0) {
+	if (strcmp (line, EMPTY_ARCHIVE_WARNING) == 0) {
 		FR_COMMAND_ZIP (comm)->is_empty = TRUE;
 		return;
 	}
@@ -199,8 +198,7 @@ list__process_line (char     *line,
 	else
 		fdata->name = g_strdup (file_name_from_path (fdata->full_path));
 	fdata->path = remove_level_from_path (fdata->full_path);
-	
-	
+
 	if (*fdata->name == 0)
 		file_data_free (fdata);
 	else
@@ -209,7 +207,7 @@ list__process_line (char     *line,
 
 
 static void
-add_filename_arg (FRCommand *comm) 
+add_filename_arg (FrCommand *comm)
 {
 	char *temp = prepend_path_separator (comm->e_filename);
 	fr_process_add_arg (comm->process, temp);
@@ -218,7 +216,7 @@ add_filename_arg (FRCommand *comm)
 
 
 static void
-add_password_arg (FRCommand     *comm,
+add_password_arg (FrCommand     *comm,
 		  const char    *password,
 		  gboolean       always_specify)
 {
@@ -242,12 +240,12 @@ add_password_arg (FRCommand     *comm,
 
 
 static void
-fr_command_zip_list (FRCommand  *comm,
+fr_command_zip_list (FrCommand  *comm,
 		     const char *password)
 {
 	FR_COMMAND_ZIP (comm)->is_empty = FALSE;
 
-	fr_process_set_out_line_func (FR_COMMAND (comm)->process, 
+	fr_process_set_out_line_func (FR_COMMAND (comm)->process,
 				      list__process_line,
 				      comm);
 
@@ -260,10 +258,10 @@ fr_command_zip_list (FRCommand  *comm,
 
 
 static void
-process_line__common (char     *line, 
+process_line__common (char     *line,
 		      gpointer  data)
 {
-	FRCommand  *comm = FR_COMMAND (data);
+	FrCommand  *comm = FR_COMMAND (data);
 
 	if (line == NULL)
 		return;
@@ -278,7 +276,7 @@ process_line__common (char     *line,
 
 
 static void
-fr_command_zip_add (FRCommand     *comm,
+fr_command_zip_add (FrCommand     *comm,
 		    GList         *file_list,
 		    const char    *base_dir,
 		    gboolean       update,
@@ -287,13 +285,13 @@ fr_command_zip_add (FRCommand     *comm,
 {
 	GList *scan;
 
-	fr_process_set_out_line_func (FR_COMMAND (comm)->process, 
+	fr_process_set_out_line_func (FR_COMMAND (comm)->process,
 				      process_line__common,
 				      comm);
 
 	fr_process_begin_command (comm->process, "zip");
 
-	if (base_dir != NULL) 
+	if (base_dir != NULL)
 		fr_process_set_working_dir (comm->process, base_dir);
 
 	/* preserve links. */
@@ -328,12 +326,12 @@ fr_command_zip_add (FRCommand     *comm,
 
 
 static void
-fr_command_zip_delete (FRCommand *comm,
+fr_command_zip_delete (FrCommand *comm,
 		       GList     *file_list)
 {
 	GList *scan;
 
-	fr_process_set_out_line_func (FR_COMMAND (comm)->process, 
+	fr_process_set_out_line_func (FR_COMMAND (comm)->process,
 				      process_line__common,
 				      comm);
 
@@ -352,7 +350,7 @@ fr_command_zip_delete (FRCommand *comm,
 
 
 static void
-fr_command_zip_extract (FRCommand  *comm,
+fr_command_zip_extract (FrCommand  *comm,
 			GList      *file_list,
 			const char *dest_dir,
 			gboolean    overwrite,
@@ -362,12 +360,12 @@ fr_command_zip_extract (FRCommand  *comm,
 {
 	GList *scan;
 
-	fr_process_set_out_line_func (FR_COMMAND (comm)->process, 
+	fr_process_set_out_line_func (FR_COMMAND (comm)->process,
 				      process_line__common,
 				      comm);
 
 	fr_process_begin_command (comm->process, "unzip");
-	
+
 	if (dest_dir != NULL) {
 		char *e_dest_dir = fr_command_escape (comm, dest_dir);
 		fr_process_add_arg (comm->process, "-d");
@@ -401,7 +399,7 @@ fr_command_zip_extract (FRCommand  *comm,
 
 
 static void
-fr_command_zip_test (FRCommand   *comm,
+fr_command_zip_test (FrCommand   *comm,
 		     const char  *password)
 {
 	fr_process_begin_command (comm->process, "unzip");
@@ -413,30 +411,48 @@ fr_command_zip_test (FRCommand   *comm,
 
 
 static void
-fr_command_zip_handle_error (FRCommand   *comm, 
+fr_command_zip_handle_error (FrCommand   *comm,
 			     FRProcError *error)
 {
-	if (error->type == FR_PROC_ERROR_GENERIC) {
+	if (error->type == FR_PROC_ERROR_COMMAND_ERROR) {
 		if (error->status <= 1)
 			error->type = FR_PROC_ERROR_NONE;
 		else if ((error->status == 82) || (error->status == 5))
 			error->type = FR_PROC_ERROR_ASK_PASSWORD;
+		else {
+			GList *output;
+			GList *scan;
+			
+			if (comm->action == FR_ACTION_TESTING_ARCHIVE)
+				output = comm->process->raw_output;
+			else
+				output = comm->process->raw_error;
+			
+			for (scan = g_list_last (output); scan; scan = scan->prev) {
+				char *line = scan->data;
+				
+				if (strstr (line, "incorrect password") != NULL) {
+					error->type = FR_PROC_ERROR_ASK_PASSWORD;
+					break;
+				}
+			}
+		}
 	}
 }
 
 
-static void 
-fr_command_zip_class_init (FRCommandZipClass *class)
+static void
+fr_command_zip_class_init (FrCommandZipClass *class)
 {
-        GObjectClass   *gobject_class = G_OBJECT_CLASS (class);
-        FRCommandClass *afc;
+	GObjectClass   *gobject_class = G_OBJECT_CLASS (class);
+	FrCommandClass *afc;
 
-        parent_class = g_type_class_peek_parent (class);
-	afc = (FRCommandClass*) class;
+	parent_class = g_type_class_peek_parent (class);
+	afc = (FrCommandClass*) class;
 
 	gobject_class->finalize = fr_command_zip_finalize;
 
-        afc->list           = fr_command_zip_list;
+	afc->list           = fr_command_zip_list;
 	afc->add            = fr_command_zip_add;
 	afc->delete         = fr_command_zip_delete;
 	afc->extract        = fr_command_zip_extract;
@@ -446,14 +462,14 @@ fr_command_zip_class_init (FRCommandZipClass *class)
 	afc->escape         = fr_command_zip_escape;
 }
 
- 
-static void 
-fr_command_zip_init (FRCommand *comm)
+
+static void
+fr_command_zip_init (FrCommand *comm)
 {
 	comm->file_type = FR_FILE_TYPE_ZIP;
 
-	comm->propAddCanUpdate             = TRUE; 
-	comm->propAddCanReplace            = TRUE; 
+	comm->propAddCanUpdate             = TRUE;
+	comm->propAddCanReplace            = TRUE;
 	comm->propExtractCanAvoidOverwrite = TRUE;
 	comm->propExtractCanSkipOlder      = TRUE;
 	comm->propExtractCanJunkPaths      = TRUE;
@@ -464,14 +480,14 @@ fr_command_zip_init (FRCommand *comm)
 }
 
 
-static void 
+static void
 fr_command_zip_finalize (GObject *object)
 {
-        g_return_if_fail (object != NULL);
-        g_return_if_fail (FR_IS_COMMAND_ZIP (object));
+	g_return_if_fail (object != NULL);
+	g_return_if_fail (FR_IS_COMMAND_ZIP (object));
 
 	/* Chain up */
-        if (G_OBJECT_CLASS (parent_class)->finalize)
+	if (G_OBJECT_CLASS (parent_class)->finalize)
 		G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
@@ -479,17 +495,17 @@ fr_command_zip_finalize (GObject *object)
 GType
 fr_command_zip_get_type ()
 {
-        static GType type = 0;
+	static GType type = 0;
 
-        if (! type) {
-                GTypeInfo type_info = {
-			sizeof (FRCommandZipClass),
+	if (! type) {
+		GTypeInfo type_info = {
+			sizeof (FrCommandZipClass),
 			NULL,
 			NULL,
 			(GClassInitFunc) fr_command_zip_class_init,
 			NULL,
 			NULL,
-			sizeof (FRCommandZip),
+			sizeof (FrCommandZip),
 			0,
 			(GInstanceInitFunc) fr_command_zip_init
 		};
@@ -498,17 +514,17 @@ fr_command_zip_get_type ()
 					       "FRCommandZip",
 					       &type_info,
 					       0);
-        }
+	}
 
-        return type;
+	return type;
 }
 
 
-FRCommand *
-fr_command_zip_new (FRProcess  *process,
+FrCommand *
+fr_command_zip_new (FrProcess  *process,
 		    const char *filename)
 {
-	FRCommand *comm;
+	FrCommand *comm;
 
 	if (!is_program_in_path ("zip") &&
 	    !is_program_in_path ("unzip")) {
