@@ -33,34 +33,47 @@
 
 enum {
 	START,
-        DONE,
+	DONE,
 	PROGRESS,
 	MESSAGE,
-        LAST_SIGNAL
+	LAST_SIGNAL
 };
 
 static GObjectClass *parent_class = NULL;
 static guint fr_command_signals[LAST_SIGNAL] = { 0 };
 
-static void fr_command_class_init  (FRCommandClass *class);
-static void fr_command_init        (FRCommand *afile);
+static void fr_command_class_init  (FrCommandClass *class);
+static void fr_command_init        (FrCommand *afile);
 static void fr_command_finalize    (GObject *object);
 
+char *action_names[] = { "NONE",
+			 "CREATING_NEW_ARCHIVE", 
+			 "LOADING_ARCHIVE", 
+			 "LISTING_CONTENT", 
+			 "DELETING_FILES", 
+			 "TESTING_ARCHIVE", 
+			 "GETTING_FILE_LIST", 
+			 "COPYING_FILES_FROM_REMOTE", 
+			 "ADDING_FILES", 
+			 "EXTRACTING_FILES", 
+			 "COPYING_FILES_TO_REMOTE", 
+			 "CREATING_ARCHIVE", 
+			 "SAVING_REMOTE_ARCHIVE" };
 
 GType
 fr_command_get_type ()
 {
-        static GType type = 0;
+	static GType type = 0;
 
-        if (! type) {
-                GTypeInfo type_info = {
-			sizeof (FRCommandClass),
+	if (! type) {
+		GTypeInfo type_info = {
+			sizeof (FrCommandClass),
 			NULL,
 			NULL,
 			(GClassInitFunc) fr_command_class_init,
 			NULL,
 			NULL,
-			sizeof (FRCommand),
+			sizeof (FrCommand),
 			0,
 			(GInstanceInitFunc) fr_command_init
 		};
@@ -71,19 +84,19 @@ fr_command_get_type ()
 					       0);
 	}
 
-        return type;
+	return type;
 }
 
 
 static void
-base_fr_command_list (FRCommand  *comm,
+base_fr_command_list (FrCommand  *comm,
 		      const char *password)
 {
 }
 
 
 static void
-base_fr_command_add (FRCommand     *comm,
+base_fr_command_add (FrCommand     *comm,
 		     GList         *file_list,
 		     const char    *base_dir,
 		     gboolean       update,
@@ -94,14 +107,14 @@ base_fr_command_add (FRCommand     *comm,
 
 
 static void
-base_fr_command_delete (FRCommand *comm,
+base_fr_command_delete (FrCommand *comm,
 			GList     *file_list)
 {
 }
 
 
 static void
-base_fr_command_extract (FRCommand  *comm,
+base_fr_command_extract (FrCommand  *comm,
 			 GList      *file_list,
 			 const char *dest_dir,
 			 gboolean    overwrite,
@@ -113,27 +126,27 @@ base_fr_command_extract (FRCommand  *comm,
 
 
 static void
-base_fr_command_test (FRCommand   *comm,
+base_fr_command_test (FrCommand   *comm,
 		      const char  *password)
 {
 }
 
 
 static void
-base_fr_command_uncompress (FRCommand *comm)
+base_fr_command_uncompress (FrCommand *comm)
 {
 }
 
 
 static void
-base_fr_command_recompress (FRCommand     *comm,
+base_fr_command_recompress (FrCommand     *comm,
 			    FRCompression  compression)
 {
 }
 
 
 char *
-base_fr_command_escape (FRCommand     *comm,
+base_fr_command_escape (FrCommand     *comm,
 			const char    *str)
 {
 	return shell_escape (str);
@@ -141,24 +154,24 @@ base_fr_command_escape (FRCommand     *comm,
 
 
 static void
-base_fr_command_handle_error (FRCommand *comm, 
+base_fr_command_handle_error (FrCommand *comm,
 			      FRProcError *error)
 {
 }
 
 
-static void 
-fr_command_class_init (FRCommandClass *class)
+static void
+fr_command_class_init (FrCommandClass *class)
 {
-        GObjectClass *gobject_class = G_OBJECT_CLASS (class);
+	GObjectClass *gobject_class = G_OBJECT_CLASS (class);
 
-        parent_class = g_type_class_peek_parent (class);
+	parent_class = g_type_class_peek_parent (class);
 
 	fr_command_signals[START] =
-                g_signal_new ("start",
+		g_signal_new ("start",
 			      G_TYPE_FROM_CLASS (class),
 			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (FRCommandClass, start),
+			      G_STRUCT_OFFSET (FrCommandClass, start),
 			      NULL, NULL,
 			      fr_marshal_VOID__INT,
 			      G_TYPE_NONE, 
@@ -167,7 +180,7 @@ fr_command_class_init (FRCommandClass *class)
 		g_signal_new ("done",
 			      G_TYPE_FROM_CLASS (class),
 			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (FRCommandClass, done),
+			      G_STRUCT_OFFSET (FrCommandClass, done),
 			      NULL, NULL,
 			      fr_marshal_VOID__INT_POINTER,
 			      G_TYPE_NONE, 2,
@@ -177,7 +190,7 @@ fr_command_class_init (FRCommandClass *class)
 		g_signal_new ("progress",
 			      G_TYPE_FROM_CLASS (class),
 			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (FRCommandClass, progress),
+			      G_STRUCT_OFFSET (FrCommandClass, progress),
 			      NULL, NULL,
 			      fr_marshal_VOID__DOUBLE,
 			      G_TYPE_NONE, 1,
@@ -186,13 +199,13 @@ fr_command_class_init (FRCommandClass *class)
 		g_signal_new ("message",
 			      G_TYPE_FROM_CLASS (class),
 			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (FRCommandClass, message),
+			      G_STRUCT_OFFSET (FrCommandClass, message),
 			      NULL, NULL,
 			      fr_marshal_VOID__STRING,
 			      G_TYPE_NONE, 1,
 			      G_TYPE_STRING);
 
-        gobject_class->finalize = fr_command_finalize;
+	gobject_class->finalize = fr_command_finalize;
 
 	class->list           = base_fr_command_list;
 	class->add            = base_fr_command_add;
@@ -213,8 +226,8 @@ fr_command_class_init (FRCommandClass *class)
 }
 
 
-static void 
-fr_command_init (FRCommand *comm)
+static void
+fr_command_init (FrCommand *comm)
 {
 	comm->filename = NULL;
 	comm->e_filename = NULL;
@@ -234,27 +247,28 @@ fr_command_init (FRCommand *comm)
 }
 
 
-static void 
-fr_command_start (FRProcess *process,
+static void
+fr_command_start (FrProcess *process,
 		  gpointer   data)
 {
-	FRCommand *comm = FR_COMMAND (data);
-	g_signal_emit (G_OBJECT (comm), 
+	FrCommand *comm = FR_COMMAND (data);
+	
+	g_signal_emit (G_OBJECT (comm),
 		       fr_command_signals[START], 
 		       0,
 		       comm->action);
 }
 
 
-static void 
-fr_command_done (FRProcess   *process,
+static void
+fr_command_done (FrProcess   *process,
 		 FRProcError *error, 
 		 gpointer     data)
 {
-	FRCommand *comm = FR_COMMAND (data);
+	FrCommand *comm = FR_COMMAND (data);
 
 	comm->process->restart = FALSE;
-	if (error->type != FR_PROC_ERROR_NONE) 
+	if (error->type != FR_PROC_ERROR_NONE)
 		fr_command_handle_error (comm, error);
 
 	if (comm->process->restart)
@@ -269,33 +283,33 @@ fr_command_done (FRProcess   *process,
 
 
 void
-fr_command_construct (FRCommand  *comm,
-		      FRProcess  *process,
+fr_command_construct (FrCommand  *comm,
+		      FrProcess  *process,
 		      const char *fr_command_name)
 {
 	fr_command_set_filename (comm, fr_command_name);
 
 	g_object_ref (G_OBJECT (process));
 	comm->process = process;
-	g_signal_connect (G_OBJECT (comm->process), 
+	g_signal_connect (G_OBJECT (comm->process),
 			  "start",
 			  G_CALLBACK (fr_command_start),
 			  comm);
-	g_signal_connect (G_OBJECT (comm->process), 
+	g_signal_connect (G_OBJECT (comm->process),
 			  "done",
 			  G_CALLBACK (fr_command_done),
 			  comm);
 }
 
 
-static void 
+static void
 fr_command_finalize (GObject *object)
 {
-        FRCommand* comm;
+	FrCommand* comm;
+
+	g_return_if_fail (object != NULL);
+	g_return_if_fail (FR_IS_COMMAND (object));
 
-        g_return_if_fail (object != NULL);
-        g_return_if_fail (FR_IS_COMMAND (object));
-  
 	comm = FR_COMMAND (object);
 
 	if (comm->filename != NULL)
@@ -305,13 +319,13 @@ fr_command_finalize (GObject *object)
 		g_free (comm->e_filename);
 
 	if (comm->file_list != NULL) {
-		g_list_foreach (comm->file_list, 
-				(GFunc) file_data_free, 
+		g_list_foreach (comm->file_list,
+				(GFunc) file_data_free,
 				NULL);
 		g_list_free (comm->file_list);
 	}
 
-	g_signal_handlers_disconnect_matched (G_OBJECT (comm->process), 
+	g_signal_handlers_disconnect_matched (G_OBJECT (comm->process),
 					      G_SIGNAL_MATCH_DATA, 
 					      0, 
 					      0, NULL, 
@@ -320,13 +334,13 @@ fr_command_finalize (GObject *object)
 	g_object_unref (G_OBJECT (comm->process));
 
 	/* Chain up */
-        if (G_OBJECT_CLASS (parent_class)->finalize)
+	if (G_OBJECT_CLASS (parent_class)->finalize)
 		G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
 
 void
-fr_command_set_filename (FRCommand *comm,
+fr_command_set_filename (FrCommand  *comm,
 			 const char *filename)
 {
 	g_return_if_fail (FR_IS_COMMAND (comm));
@@ -340,12 +354,12 @@ fr_command_set_filename (FRCommand *comm,
 	if (! g_path_is_absolute (filename)) {
 		char *current_dir;
 		current_dir = g_get_current_dir ();
-		comm->filename = g_strconcat (current_dir, 
+		comm->filename = g_strconcat (current_dir,
 					      "/", 
 					      filename, 
 					      NULL);
 		g_free (current_dir);
-	} else 
+	} else
 		comm->filename = g_strdup (filename);
 
 	comm->e_filename = shell_escape (comm->filename);
@@ -356,7 +370,7 @@ fr_command_set_filename (FRCommand *comm,
 
 
 void
-fr_command_list (FRCommand  *comm,
+fr_command_list (FrCommand  *comm,
 		 const char *password)
 {
 	g_return_if_fail (FR_IS_COMMAND (comm));
@@ -369,17 +383,17 @@ fr_command_list (FRCommand  *comm,
 		comm->file_list = NULL;
 	}
 
-	comm->action = FR_ACTION_LIST;
+	comm->action = FR_ACTION_LISTING_CONTENT;
 	fr_process_set_out_line_func (FR_COMMAND (comm)->process, NULL, NULL);
 	fr_process_set_err_line_func (FR_COMMAND (comm)->process, NULL, NULL);
-
-	if (!comm->fake_load) 
+	
+	if (!comm->fake_load)
 		FR_COMMAND_GET_CLASS (G_OBJECT (comm))->list (comm, password);
 }
 
 
 void
-fr_command_add (FRCommand     *comm,
+fr_command_add (FrCommand     *comm,
 		GList         *file_list,
 		const char    *base_dir,
 		gboolean       update,
@@ -388,10 +402,11 @@ fr_command_add (FRCommand     *comm,
 {
 	fr_command_progress (comm, -1.0);
 
-	comm->action = FR_ACTION_ADD;
+	comm->action = FR_ACTION_ADDING_FILES;
 	fr_process_set_out_line_func (FR_COMMAND (comm)->process, NULL, NULL);
 	fr_process_set_err_line_func (FR_COMMAND (comm)->process, NULL, NULL);
-	FR_COMMAND_GET_CLASS (G_OBJECT (comm))->add (comm, 
+	
+	FR_COMMAND_GET_CLASS (G_OBJECT (comm))->add (comm,
 						     file_list,
 						     base_dir,
 						     update,
@@ -401,20 +416,21 @@ fr_command_add (FRCommand     *comm,
 
 
 void
-fr_command_delete (FRCommand *comm,
+fr_command_delete (FrCommand *comm,
 		   GList *file_list)
 {
 	fr_command_progress (comm, -1.0);
 
-	comm->action = FR_ACTION_DELETE;
+	comm->action = FR_ACTION_DELETING_FILES;
 	fr_process_set_out_line_func (FR_COMMAND (comm)->process, NULL, NULL);
 	fr_process_set_err_line_func (FR_COMMAND (comm)->process, NULL, NULL);
+	
 	FR_COMMAND_GET_CLASS (G_OBJECT (comm))->delete (comm, file_list);
 }
 
 
 void
-fr_command_extract (FRCommand  *comm,
+fr_command_extract (FrCommand  *comm,
 		    GList      *file_list,
 		    const char *dest_dir,
 		    gboolean    overwrite,
@@ -424,10 +440,11 @@ fr_command_extract (FRCommand  *comm,
 {
 	fr_command_progress (comm, -1.0);
 
-	comm->action = FR_ACTION_EXTRACT;
+	comm->action = FR_ACTION_EXTRACTING_FILES;
 	fr_process_set_out_line_func (FR_COMMAND (comm)->process, NULL, NULL);
 	fr_process_set_err_line_func (FR_COMMAND (comm)->process, NULL, NULL);
-	FR_COMMAND_GET_CLASS (G_OBJECT (comm))->extract (comm, 
+	
+	FR_COMMAND_GET_CLASS (G_OBJECT (comm))->extract (comm,
 							 file_list, 
 							 dest_dir,
 							 overwrite,
@@ -438,20 +455,21 @@ fr_command_extract (FRCommand  *comm,
 
 
 void
-fr_command_test (FRCommand   *comm,
+fr_command_test (FrCommand   *comm,
 		 const char  *password)
 {
 	fr_command_progress (comm, -1.0);
 
-	comm->action = FR_ACTION_TEST;
+	comm->action = FR_ACTION_TESTING_ARCHIVE;
 	fr_process_set_out_line_func (FR_COMMAND (comm)->process, NULL, NULL);
 	fr_process_set_err_line_func (FR_COMMAND (comm)->process, NULL, NULL);
+	
 	FR_COMMAND_GET_CLASS (G_OBJECT (comm))->test (comm, password);
 }
 
 
 void
-fr_command_uncompress (FRCommand *comm)
+fr_command_uncompress (FrCommand *comm)
 {
 	fr_command_progress (comm, -1.0);
 	FR_COMMAND_GET_CLASS (G_OBJECT (comm))->uncompress (comm);
@@ -459,33 +477,33 @@ fr_command_uncompress (FRCommand *comm)
 
 
 void
-fr_command_recompress (FRCommand     *comm,
+fr_command_recompress (FrCommand     *comm,
 		       FRCompression  compression)
 {
-	fr_command_progress (comm, -1.0);
+	fr_command_progress (comm, -1.0);	
 	FR_COMMAND_GET_CLASS (G_OBJECT (comm))->recompress (comm, compression);
 }
 
 
 char *
-fr_command_escape (FRCommand     *comm,
+fr_command_escape (FrCommand     *comm,
 		   const char    *str)
 {
 	return FR_COMMAND_GET_CLASS (G_OBJECT (comm))->escape (comm, str);
 }
 
 
-/* fraction == -1 means : I don't known how much time the current operation 
+/* fraction == -1 means : I don't known how much time the current operation
  *                        will take, the dialog will display this info pulsing 
  *                        the progress bar. 
  * fraction in [0.0, 1.0] means the amount of work, in percentage, 
  *                        accomplished. 
  */
 void
-fr_command_progress (FRCommand     *comm,
+fr_command_progress (FrCommand     *comm,
 		     double         fraction)
 {
-	g_signal_emit (G_OBJECT (comm), 
+	g_signal_emit (G_OBJECT (comm),
 		       fr_command_signals[PROGRESS], 
 		       0,
 		       fraction);
@@ -493,10 +511,10 @@ fr_command_progress (FRCommand     *comm,
 
 
 void
-fr_command_message (FRCommand     *comm,
+fr_command_message (FrCommand     *comm,
 		    const char    *msg)
 {
-	g_signal_emit (G_OBJECT (comm), 
+	g_signal_emit (G_OBJECT (comm),
 		       fr_command_signals[MESSAGE], 
 		       0,
 		       msg);
@@ -504,7 +522,7 @@ fr_command_message (FRCommand     *comm,
 
 
 void
-fr_command_set_n_files (FRCommand     *comm,
+fr_command_set_n_files (FrCommand     *comm,
 			int            n_files)
 {
 	comm->n_files = n_files;
@@ -513,7 +531,7 @@ fr_command_set_n_files (FRCommand     *comm,
 
 
 void
-fr_command_handle_error (FRCommand *comm,
+fr_command_handle_error (FrCommand *comm,
 			 FRProcError *error)
 {
 	FR_COMMAND_GET_CLASS (G_OBJECT (comm))->handle_error (comm, error);
